@@ -20,6 +20,7 @@ import inspect
 import re;
 import json;
 import datetime
+from fractions import Fraction
 
 if (platform == "Windows"):
     from win32com.client import Dispatch
@@ -190,13 +191,16 @@ class LA:
         return s;
 
     @staticmethod
-    def M(m, name="", call_display=True, showdim=True, precision=4):
+    def M(m, name="", useFrac=False, call_display=True, showdim=True, precision=4):
         np.set_printoptions(precision=precision, linewidth=180)
         name = name + " =" if name != "" else ""
         dim = "";
         if (showdim):
             dim = " \\times ".join(map(str, (m.shape) )) ;
-        s = str(m)
+        if (useFrac):
+            m=np.array([ str(Fraction(_).limit_denominator()) for _ in m.flat]).reshape(m.shape)
+        s = str(m).replace("'", '')
+        s=s.replace('\\\\', '\\')
         s = s.replace('[', '')
         s = s.replace(']', '')
         s = s.replace('\n', '\\\\\\\\<NEW-LINE>')
@@ -210,15 +214,28 @@ class LA:
             display(Math(s))
         return s;
 
-
     #Display thr matrix
     @staticmethod
-    def display(*M):
+    def display(*M, names=None):
         s = ""
-        for m in M:
-            s+= LA.M(m, call_display=False, showdim=False);
+        if (names is None):
+            names = ["" for i in range(len(M)) ]
+        for i, m in enumerate(M):
+            s+= LA.M(m, name=names[i], call_display=False, showdim=False);
         display(Math(s))
 
+    #Display thr matrix
+    def Matdisplay(*M, names=None, useFractions=False, display=False):
+        s = ""
+        if (names is None):
+            names = ["" for i in range(len(M)) ]
+        for i, m in enumerate(M):
+            s+= LA.M(m, name=names[i], useFrac=useFractions, call_display=False, showdim=False);
+
+        if (display):
+            display(Math(s))
+        return (s)
+
     def d(self):
         self.display(self.a, self.name)
         return self.a
@@ -401,13 +418,13 @@ def plthist(x, y=None, bins='auto', alpha=0.75, title=None, grid = True, xlabel=
 Print analysis on the Pandas dataframe
 =======================================================================================
 '''
-def searchDF(df, s="", cols=[], maxRows=10):
+def searchDFInColumns(df, s="", cols=[], maxRows=10):
     rows=[]    
     for i, r in df.iterrows():
         for j, c in r.iteritems():
             if (len(cols) > 0 and not c in cols):
                 break;
-            if ( re.match(s, str(c)) ):
+            if ( re.search(s, str(c), flags=re.M|re.DOTALL|re.I) ):
                 maxRows = maxRows -1;
                 rows.append(i)
                 break;
@@ -415,7 +432,19 @@ def searchDF(df, s="", cols=[], maxRows=10):
             break
     df1 = df.iloc[rows];
     return df1;
-    
+
+def searchDF(df, s="", maxRows=10):
+    rows=[]    
+    for i, r in df.iterrows():
+        for c in r.values:
+            if re.search(s,str(c), flags=re.M|re.DOTALL|re.I):
+                maxRows = maxRows -1;
+                rows.append(i)
+                break;
+        if (maxRows ==0 or i > 50):
+            break
+    df1 = df.ix[rows];
+    return df1;
 
 def colTypesDF(df):
     dfTypes=pd.DataFrame(df.dtypes)
@@ -559,6 +588,8 @@ def getHTMLTableRows(dff, startRow=0, maxRows = 5):
         ddd=dff[startRow:e]
 
     vals = re.findall('<td>(.*?)</td>',  ddd.to_html(), flags=re.DOTALL|re.M|re.MULTILINE|re.IGNORECASE)
+    vals = [v.replace("'", '\\\'') for v in vals]
+    vals = [v.replace("\n", '\\n') for v in vals]
     
     if (dff.index.dtype_str.startswith('datetime')):
         idxs = list(ddd.index.astype(str))
@@ -592,7 +623,9 @@ def getHTMLTableRowsFromIndex(dff, idx=0, dispRows = 5, goBack=True):
     ddd=dff[startRow:e]
 
     vals = re.findall('<td>(.*?)</td>',  ddd.to_html(), flags=re.DOTALL|re.M|re.MULTILINE|re.IGNORECASE)
-    
+    vals = [v.replace("'", '\\\'') for v in vals]
+    vals = [v.replace("\n", '\\n') for v in vals]
+   
     if (dff.index.dtype_str.startswith('datetime')):
         idxs = list(ddd.index.astype(str))
     else:
@@ -693,8 +726,12 @@ $("#<TABLE_ID> th").resizable()
 </script>
 ''';
 
-def displayDFs(dfs, maxrows = 6, startrow=0, showTypes = False, showIcons=True, tableID=None, showNav= True,
-               search=None, cols=[],  showStats = False, editable=True, useMyStyle=True, donotDisplay=False ):
+def displayDFs(dfs, maxrows = 6, startrow=0, showTypes = False, showIcons=True,
+               tableID=None, 
+               showNav= True, title=None,
+               search=None, cols=[],  showStats = False, editable=True,
+               useMyStyle=True,
+               donotDisplay=False ):
                    
     if ( type(dfs) !=list and type(dfs) != tuple):
         dfs = [dfs];
@@ -728,7 +765,9 @@ def displayDFs(dfs, maxrows = 6, startrow=0, showTypes = False, showIcons=True,
             h = h.replace("<table ", "<table wwidth=100% ")
         #
         if (editable):
-            h = h.replace("<td", "<td contenteditable ")
+            nw= "<td style='white-space: nowrap;' contenteditable "
+            #h = h.replace("<td","<td contenteditable ")
+            h = h.replace("<td",nw)
         #
         if (useMyStyle):
             h = h.replace("class='dataframe'", "class='ourTableStyle' ")
@@ -774,7 +813,9 @@ def displayDFs(dfs, maxrows = 6, startrow=0, showTypes = False, showIcons=True,
     
         
         tabSep = "<td>&nbsp;</td>" if len(dfs) > 1 else "";
-        otr += "<td style='text-align:left;' bgcolor=" + bg + ">" + dim + " var: " + dfVarNme + "<br>\n" + h + "</td>{}".format(tabSep)
+        tit = title[i] if (type(title) == list) else title;
+        tit = tit + " " + dim if (tit is not None) else dim
+        otr += "<td style='text-align:left;' bgcolor=" + bg + ">" + tit + " var: " + dfVarNme + "<br>\n" + h + "</td>{}".format(tabSep)
     otr += "</tr></table>"
     if (not donotDisplay):
         display(HTML(otr))
